@@ -23,7 +23,7 @@ HOME_DIR_CREATE = f"mkdir {HOME_DIR}/.sylo"
 DATA_FILE_CREATE = f'echo "{TODAY_STR},0,0" > {DATA_FILE_LOCATION}'
 TASK_FILE_CREATE = f"touch {TASK_FILE_LOCATION}"
 
-WELCOME_CHOICES = ("", "h", "q", "s", "i", "t", "n", "y", "a")
+WELCOME_CHOICES = ("", "h", "q", "s", "i", "t", "y", "a")
 
 TIMER_DEFAULTS = {
     "work": {
