@@ -27,12 +27,13 @@ class Display:
             self.print_header_small()
             self.print_tasks(tasks)
             print(
-                f"{self.col('Ctrl-C to stop timer early.')}"
+                f"{self.col('Press')} {self.col('Ctrl-C', 'yellow')} {self.col('to stop timer early.')}"
                 "\n"
                 f"\n{self.col('WORK', 'red')} "
                 f"for {self.col(str(timer_val), 'yellow')} minutes"
             )
         else:
+            self.print_header_small()
             print(
                 f"Ctrl-C to stop timer early."
                 f"\n{self.col('REST', 'green')} "
@@ -67,35 +68,36 @@ class Display:
         print(
             "Additional commands;"
             f"\n{self.col('S', 'yellow')}{self.col('       --    Swap upcoming timer')}"
-            f"\n{self.col('T', 'yellow')}{self.col('       --    Toggle display of tasks for today')}"
-            f"\n{self.col('Y', 'yellow')}{self.col('       --    Toggle display of tasks for yesterday')}"
-            f"\n{self.col('N', 'yellow')}{self.col('       --    Add new tasks for today')}"
-            f"\n{self.col('I', 'yellow')}{self.col('       --    Show insights')}"
+            f"\n{self.col('T', 'yellow')}{self.col('       --    Show task view')}"
+            f"\n{self.col('I', 'yellow')}{self.col('       --    Show insights view')}"
             f"\n{self.col('Q', 'yellow')}{self.col('       --    Quit')}"
         )
 
     def print_splash_prompt(self):
         print(
-            f"{self.col('Press')} {self.col('ENTER', 'yellow')} {self.col('to start the next timer.')}"
+            f"{self.col('Press')} "
+            f"{self.col('ENTER', 'yellow')} "
+            f"{self.col('to start the next timer.')}"
         )
 
+    def print_today_yesterday_tasks(self, day: str):
+        print(f"{self.col(day)}\n")
+
     def print_offer_options(self):
         print(f"{self.col('Press')} {self.col('H', 'yellow')} {self.col('for Help.')}")
 
     def print_add_task_or_quit(self):
         print(
+            f"{self.col('Press')} "
             f"{self.col('ENTER', 'yellow')} "
-            f"{self.col('to add a new task or')} "
-            f"{self.col('Q', 'yellow')} "
-            f"{self.col('to go back')}"
+            f"{self.col('to go back, or')} "
+            f"{self.col('N', 'yellow')} "
+            f"{self.col('to add a new task')}"
         )
 
     def print_new_task(self):
         print(f"{self.col('Input a new task')}")
 
-    def print_another_task(self):
-        print(f"{self.col('Input another? Y/N')}")
-
     def print_splash(self, durations: Durations, mode: str):
         print(
             f"Total {self.col('work', 'red')} today:           "
@@ -135,7 +137,8 @@ class Display:
     def print_tasks(self, tasks: List = None):
         if tasks:
             print(f'{self.col(f"Tasks", "yellow")}')
-            print("\n".join("".join(map(str, f"{t[0]} -- {t[1]}")) for t in tasks))
+            print("\n".join("".join(map(str, f"{self.col(t[0], 'yellow')}   "
+                                             f"{t[1]}   --  {t[2]}")) for t in tasks))
             print("\n")
 
     def print_header_small(self):
