@@ -11,6 +11,8 @@ from sylo.definitions import (
 from sylo.utils import check_for_file, mins_to_secs
 import tomli
 import csv
+from typing import List
+
 
 logger = logging.getLogger(__name__)
 
@@ -143,8 +145,15 @@ def get_tasks(date: str = None):
             csv_reader = csv.reader(read_obj)
             logger.info(f"Returning tasks for {date}")
             if date:
-                return [row for row in csv_reader if row[0] == date]
+                return [row for row in csv_reader if row[1] == date]
             else:
                 return [row for row in csv_reader]
     except Exception as e:
         print(e)
+
+
+def get_max_id_in_csv(tasks: List):
+    if tasks:
+        return max(t[0] for t in tasks)
+    else:
+        return 0
